@@ -337,35 +337,43 @@ class Client(Singleton):
     async def get_mq_conn(self):
         return await self.mq.get_mq_conn()
 
-    async def put_from_cloud_async(self, url, bucket, bucket_name, timeout=10, file_ttl=-1, mq=None):
+    async def put_from_cloud_async(self, url, bucket, bucket_name, timeout=10, file_ttl=-1):
         # save to cache
         task_id = 'tmp_file_{}_{}'.format(bucket, bucket_name)
-        ret = await self.mq.async_publish(self.put_topic, {
-            'url': url,
-            'bucket': bucket,
-            'bucket_name': bucket_name,
-            'ttl': file_ttl
-        }, mq)
+        connection = await self.mq.get_mq_conn()
+        try:
+            ret = await self.mq.async_publish(self.put_topic, {
+                'url': url,
+                'bucket': bucket,
+                'bucket_name': bucket_name,
+                'ttl': file_ttl
+            }, connection)
+            if ret:
+                await connection.close()
+                t = time.time()
+                while True:
+                    if time.time() - t >= timeout:
+                        break
+                    
+                    resp = self.redis.get(task_id)
+                    
+                    if resp is not None and len(resp) > 0:
+                        resp = json.loads(resp)
+                        if resp['ret']:
+                            return True, '{}/{}'.format(bucket, bucket_name)
+                        else:
+                            return False, resp['err']
+                    
+                    await asyncio.sleep(1/30)
+            return False, '上传出错'
+        except Exception as e:
+            return False, str(e)
+        finally:
+            if not connection.is_closed:
+                await connection.close()
         
-        if ret:
-            t = time.time()
-            while True:
-                if time.time() - t >= timeout:
-                    break
-                
-                resp = self.redis.get(task_id)
-                
-                if resp is not None and len(resp) > 0:
-                    resp = json.loads(resp)
-                    if resp['ret']:
-                        return True, '{}/{}'.format(bucket, bucket_name)
-                    else:
-                        return False, resp['err']
-                
-                await asyncio.sleep(1/30)
-        return False, '上传出错'
     
-    async def put_async(self, path, bucket, bucket_name, timeout=10, file_ttl=-1, mq=None):
+    async def put_async(self, path, bucket, bucket_name, timeout=10, file_ttl=-1):
         ret, e = self.put_to_cloud(path, bucket, bucket_name)
         if ret:
             ret, e = await self.put_from_cloud_async(e, bucket, bucket_name, timeout, file_ttl)
